| Title: | Cross-platform consensus analysis of genomic measurements via interlaboratory testing method |
|---|---|
| Description: | An implementation of the American Society for Testing and Materials (ASTM) Standard E691 for interlaboratory testing procedures, designed for cross-platform genomic measurements. Given three (3) or more genomic platforms or laboratory protocols, this package provides interlaboratory testing procedures giving per-locus comparisons for sensitivity and precision between platforms. |
| Authors: | Tim Peters |
| Maintainer: | Tim Peters <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 1.31.0 |
| Built: | 2026-05-30 08:48:05 UTC |
| Source: | https://github.com/bioc/consensus |
An implementation of the American Society for Testing and Materials (ASTM) Standard E691 for interlaboratory testing procedures, designed for cross-platform genomic measurements. Given three (3) or more genomic platforms or laboratory protocols, this package provides interlaboratory testing procedures giving per-locus comparisons for sensitivity and precision between platforms.
Tim J. Peters <[email protected]>
data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm)data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm)
Gene expression data from 27 Glioblastoma Multiforme (GBM) patients measured on a custom Agilent Gene Expression Microarray.
data("TCGA")data("TCGA")
Numeric matrix.
https://tcga-data.nci.nih.gov/docs/publications/gbm_exp/UNC202.txt
Verhaak, R. G. W., Hoadley, K. A., Purdom, E., Wang, V., Qi, Y., Wilkerson, M. D., ..., Cancer Genome Atlas Research Network. Integrated genomic analysis identifies clinically relevant subtypes of glioblastoma characterized by abnormalities in PDGFRA, IDH1, EGFR, and NF1. Cancer Cell, 2010, 17(1), 98-110.
data("TCGA")data("TCGA")
An S4 class that stores parameter value output from fitConsensus.
This class has eight slots, each containing parameters from the row-linear fit:
a_i:Platform-wise average (intercepts).
b_i:Platform-wise sensitivity (slopes).
d_i:Platform-wise precision (residual mean squares). Note that higher values correspond to lower precision.
V_a: Variance of a_i. High values indicate high discordance in dynamic range.
V_b: Variance of b_i. High values indicate high discordance in sensitivity.
V_d:Averaged precision across platforms.
z0: Point of approximate concurrence for all regression lines. Only applicable when a_i and b_i are highly correlated. See Equations 13.16 and 13.39 of Mandel (2012).
Vdelta: Residual variance about the line when b_i is regressed against a_i. Lower values indicate a higher degree of concurrence, assuming that a_i and b_i are highly correlated. See Equation 13.36 of Mandel (2012).
ConsensusFit objects have a show method that describes the dimensions of the data, in the form: "ConsensusFit object with i platforms/conditions and k measured loci".
Tim Peters <[email protected]>
Mandel, J. (2012). The statistical analysis of experimental data. Courier Corporation. Chapter 13: The Systematic Evaluation of Measuring Processes.
fitConsensus: outputs ConsensusFit objects.
The main function of this package. Fits a number of row-linear models from a MultiMeasure object, one for each matching row of the data matrices contained within it. Outputs a ConsensusFit object containing per-platform, per locus consensus values for average, sensitivity and precision.
fitConsensus(multimeas)fitConsensus(multimeas)
multimeas |
An object of class |
For each locus, a row-linear model (Mandel 1994) is fit of the form
where is a matrix of measurements at the same genomic locus , the row index labels the platform or condition (microarray, library prep method for sequencing assay etc.) used and the column index labels the biological samples that are interrogated at that locus on each of the platforms. Hence is the intercept (row averages of ), the slope of the regression line (sensitivity) and the residual mean square (precision) about the ith fitted line, noting that higher corresponds to lower precision. Values of , and can be found in the slots of the ConsensusFit object.
For MultiMeasure objects with 10,000 loci or more, a progress message is printed for every 10,000 loci fitted.
A ConsensusFit object with slots containing various parameter values from the row-linear fits. More information can be found in the linked class description. Output from this function can then be passed to various plotting functions for data exploration.
Tim Peters <[email protected]>
Mandel, J. (1994). Analyzing Interlaboratory Data According to ASTM Standard E691. In Quality and Statistics: Total Quality Management (pp. 59-59-12). 100 Barr Harbor Drive, PO Box C700, West Conshohocken, PA 19428-2959: ASTM International.
Mandel, J. (2012). The statistical analysis of experimental data. Courier Corporation. Chapter 13: “The Systematic Evaluation of Measuring Processes”.
Ku, H.H. (1969). Precision Measurement and Calibration. Volume 1. Statistical Concepts and Procedures (No. NBS-SP-300-VOL-1). Issued February 1969. US Department of Commerce. Chapter 3.7: “The Interlaboratory Evaluation of Testing Methods”. Mandel, J. and Lashof, T.W. p. 170.
data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm)data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm)
Gene expression data from 27 Glioblastoma Multiforme (GBM) patients measured on the Affymetrix HuEx GeneChip.
data("TCGA")data("TCGA")
Numeric matrix.
https://tcga-data.nci.nih.gov/docs/publications/gbm_exp/LBL202.txt
Verhaak, R. G. W., Hoadley, K. A., Purdom, E., Wang, V., Qi, Y., Wilkerson, M. D., ..., Cancer Genome Atlas Research Network. Integrated genomic analysis identifies clinically relevant subtypes of glioblastoma characterized by abnormalities in PDGFRA, IDH1, EGFR, and NF1. Cancer Cell, 2010, 17(1), 98-110.
data("TCGA")data("TCGA")
Creates a MultiMeasure object from a set of 3 or more numeric matrices, in preparation to pass to fitConsensus.
MultiMeasure(names=NA_character_, data=list())MultiMeasure(names=NA_character_, data=list())
names |
character vector contains the names of each data type (e.g. RNA-Seq, Agilent etc.). Must be the same |
data |
list of numeric matrices of identical |
A MultiMeasure contains a list of numeric matrices with identical dimensions and matching row names and column names, to which multiple row-linear models can be fit using fitConsensus. Users should pass a vector of names describing the platform/conditions the genomic measurements are made under, and a corresponding list of matrices to the data argument. A series of validity checks will be made on data correctness and a helpful error message will be returned if the structure does not conform to the above description.
a MultiMeasure object
Tim Peters <[email protected]>
MultiMeasure-class
data(TCGA) tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq))data(TCGA) tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNA-Seq"), data=list(U133A, Huex, Agilent, RNASeq))
An S4 class that stores normalised matched genomic data from multiple platforms and/or laboratory conditions (e.g. from microarrays, RNA-Seq and other sequencing assays).
This class has two slots, names and data.
names: character vector contains the names of each data type (e.g. RNA-Seq, Agilent etc.). Must be the same length as data.
data: list of numeric matrices of identical dim, rownames and colnames where each matrix contains the measurements from the platform/condition described in names. Rows of each matrix correspond to genomic features and columns to samples. Must be the same length as names.
MultiMeasure objects have a show method that describes the dimensions of the data, in the form: MultiMeasure object with i platforms/conditions, j samples and k measured loci.
Tim Peters <[email protected]>
MultiMeasure constructs MultiMeasure objects.
Plots a series of marginal densities for each platform for either (a) average, (b) sensitivity or (c) precision.
plotMarginals(consfit, param=c("average", "sensitivity", "precision"), pal=palette(), xlim=NULL, ...)plotMarginals(consfit, param=c("average", "sensitivity", "precision"), pal=palette(), xlim=NULL, ...)
consfit |
An object of class |
param |
Whether average ( |
pal |
Colour palette. Length must be at least the number of platforms/conditions. |
xlim |
Range of values to be plotted. If |
... |
Extra arguments passed to |
Precision is plotted on the log scale.
A plot to the current device.
Tim Peters <[email protected]>
data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm) plotMarginals(fit, "sensitivity", brewer.pal(n = 4, name = "Dark2"))data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm) plotMarginals(fit, "sensitivity", brewer.pal(n = 4, name = "Dark2"))
Plots a heatmap of a specified number of loci showing per-platform, values for either (a) average (), (b) sensitivity () or (c) precision () for the most discordant for each. Discordance is ranked by , or where the number of platforms/conditions.
plotMostDiscordant(consfit, param=c("average", "sensitivity", "precision"), numloci=20, pal=colorRampPalette(brewer.pal(9, "RdYlGn")))plotMostDiscordant(consfit, param=c("average", "sensitivity", "precision"), numloci=20, pal=colorRampPalette(brewer.pal(9, "RdYlGn")))
consfit |
An object of class |
param |
Whether average ( |
numloci |
The number of loci to plot. |
pal |
Colour palette. Length must be at least the number of platforms/conditions. |
A plot to the current device.
Tim Peters <[email protected]>
data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm) plotMostDiscordant(fit, "sensitivity", 25)data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) fit <- fitConsensus(tcga_mm) plotMostDiscordant(fit, "sensitivity", 25)
Plots a series of regressions of platform measurements against their consensus mean.
plotOneFit(multimeas, idx, pal=palette(), ...)plotOneFit(multimeas, idx, pal=palette(), ...)
multimeas |
An object of class |
idx |
Row index of the set of matrices in |
pal |
Color palette. Length must be at least the length of multimeas@data. |
... |
Extra arguments passed to |
Visualises a row-linear fit explicitly in the measurement space. Steeper (positive) slopes mean greater sensitivity, and greater scatter around the regression line indicates lower precision.
A plot to the current device.
Tim Peters <[email protected]>
data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) plotOneFit(tcga_mm, "TP53", brewer.pal(n = 4, name = "Dark2"))data("TCGA") tcga_mm <- MultiMeasure(names=c("U133A", "Huex", "Agilent", "RNASeq"), data=list(U133A, Huex, Agilent, RNASeq)) plotOneFit(tcga_mm, "TP53", brewer.pal(n = 4, name = "Dark2"))
Limma-voom normalised gene expression data from 27 Glioblastoma Multiforme (GBM) patients measured via RNA-Seq.
data("TCGA")data("TCGA")
Numeric matrix.
https://portal.gdc.cancer.gov/
Verhaak, R. G. W., Hoadley, K. A., Purdom, E., Wang, V., Qi, Y., Wilkerson, M. D., ..., Cancer Genome Atlas Research Network. Integrated genomic analysis identifies clinically relevant subtypes of glioblastoma characterized by abnormalities in PDGFRA, IDH1, EGFR, and NF1. Cancer Cell, 2010, 17(1), 98-110.
data("TCGA")data("TCGA")
Log-transformed gene expression data from 27 Glioblastoma Multiforme (GBM) patients measured on the Affymetrix-HT-HG-U133A GeneChip.
data("TCGA")data("TCGA")
Numeric matrix.
https://tcga-data.nci.nih.gov/docs/publications/gbm_exp/Broad202.txt
Verhaak, R. G. W., Hoadley, K. A., Purdom, E., Wang, V., Qi, Y., Wilkerson, M. D., ..., Cancer Genome Atlas Research Network. Integrated genomic analysis identifies clinically relevant subtypes of glioblastoma characterized by abnormalities in PDGFRA, IDH1, EGFR, and NF1. Cancer Cell, 2010, 17(1), 98-110.
data("TCGA")data("TCGA")